@@ -1,16 +1,16 @@
-'use strict';
+'use strict'
 
 /*
- * Copyright (c) 2013-2015 node-coap contributors.
+ * Copyright (c) 2013-2021 node-coap contributors.
  *
  * node-coap is licensed under an MIT +no-false-attribs license.
  * All rights not explicitly granted in the MIT license are reserved.
  * See the included LICENSE file for more details.
  */
 
-var Readable  = require('readable-stream').Readable
-  , util      = require('util')
-  , pktToMsg  = require('./helpers').packetToMessage
+var Readable = require('readable-stream').Readable
+  , util     = require('util')
+  , pktToMsg = require('./helpers').packetToMessage
 
 function IncomingMessage(packet, rsinfo, outSocket) {
   Readable.call(this)
