@@ -1,16 +1,16 @@
-'use strict';
+'use strict'
 
 /*
- * Copyright (c) 2013-2015 node-coap contributors.
+ * Copyright (c) 2013-2021 node-coap contributors.
  *
  * node-coap is licensed under an MIT +no-false-attribs license.
  * All rights not explicitly granted in the MIT license are reserved.
  * See the included LICENSE file for more details.
  */
 
-var Readable  = require('readable-stream').Readable
-  , util      = require('util')
-  , pktToMsg  = require('./helpers').packetToMessage
+var Readable = require('readable-stream').Readable
+  , util     = require('util')
+  , pktToMsg = require('./helpers').packetToMessage
 
 function ObserveReadStream(packet, rsinfo, outSocket) {
   Readable.call(this, { objectMode: true })
@@ -47,9 +47,12 @@ ObserveReadStream.prototype.append = function(packet) {
   }
 }
 
-ObserveReadStream.prototype.close = function() {
+ObserveReadStream.prototype.close = function(eagerDeregister) {
   this.push(null)
   this.emit('close')
+  if (eagerDeregister) {
+    this.emit('deregister')
+  }
 }
 
 // nothing to do, data will be pushed from the server
