@@ -1,4 +1,12 @@
-var coap = require('../')
+/*
+ * Copyright (c) 2013-2021 node-coap contributors.
+ *
+ * node-coap is licensed under an MIT +no-false-attribs license.
+ * All rights not explicitly granted in the MIT license are reserved.
+ * See the included LICENSE file for more details.
+ */
+
+var coap       = require('../')
 var parameters = coap.parameters
 
 describe('Parameters', function() {
@@ -9,7 +17,7 @@ describe('Parameters', function() {
 
   it('should ignore empty parameter', function() {
     //WHEN
-    coap.updateTiming();
+    coap.updateTiming()
 
     // THEN
     expect(parameters.maxRTT).to.eql(202)
@@ -26,10 +34,10 @@ describe('Parameters', function() {
       maxRetransmit: 3,
       maxLatency: 5,
       piggybackReplyMs: 6
-    };
+    }
 
     //WHEN
-    coap.updateTiming(coapTiming);
+    coap.updateTiming(coapTiming)
 
     // THEN
     expect(parameters.maxRTT).to.eql(11)
