@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2015 node-coap contributors.
+ * Copyright (c) 2013-2021 node-coap contributors.
  *
  * node-coap is licensed under an MIT +no-false-attribs license.
  * All rights not explicitly granted in the MIT license are reserved.
@@ -90,6 +90,7 @@ describe('request', function() {
   })
 
   it('should emit the errors in the req', function (done) {
+    this.timeout(20000)
     var req = request('coap://aaa.eee:' + 1234)
 
     req.once('error', function () {
@@ -206,6 +207,68 @@ describe('request', function() {
     })
   })
 
+  it('should accept a token parameter', function (done) {
+    request({
+      port: port
+      , token: Buffer.from([1,2,3,4,5,6,7,8])
+    }).end()
+
+    server.on('message', function (msg, rsinfo) {
+      try {
+        ackBack(msg, rsinfo)
+
+        var packet = parse(msg)
+        expect(packet.token).to.eql(Buffer.from([1,2,3,4,5,6,7,8]))
+        done()
+      } catch (err) {
+        done(err)
+      }
+    })
+  })
+
+  it('should ignore empty token parameter', function (done) {
+    request({
+      port: port
+      , token: Buffer.from([])
+    }).end()
+
+    server.on('message', function (msg, rsinfo) {
+      try {
+        ackBack(msg, rsinfo)
+
+        var packet = parse(msg)
+        expect(packet.token.length).to.be.above(0)
+        done()
+      } catch (err) {
+        done(err)
+      }
+    })
+  })
+
+  it('should reject too long token', function (done) {
+    var rq = request({
+      port: port
+      , token: Buffer.from([1,2,3,4,5,6,7,8,9,10])
+    })
+
+    rq.on('error', function(err) {
+      if (err.message === 'Token may be no longer than 8 bytes.')
+        // Success, this is what we were expecting
+        done()
+      else
+        // Not our error
+        done(err)
+    })
+
+    rq.end()
+
+    server.on('message', function (msg, rsinfo) {
+      // We should not see this!
+      ackBack(msg, rsinfo)
+      done(new Error('Message should not have been sent!'))
+    })
+  })
+
   it('should emit a response with a piggyback CON message', function (done) {
     var req = request({
       port: port
@@ -429,7 +492,7 @@ describe('request', function() {
           , ack: true
           , payload: 'this payload invalidates empty message'
         })
-      expect(packet.code).to.be.eq('0.01');
+      expect(packet.code).to.be.eq('0.01')
       messages++
       server.send(toSend, 0, toSend.length, rsinfo.port, rsinfo.address)
     })
@@ -1073,6 +1136,33 @@ describe('request', function() {
       })
     })
 
+    it('should send deregister request if close(eager=true)', function (done) {
+
+      var req = doObserve()
+
+      req.on('response', function (res) {
+        res.once('data', function (data) {
+          expect(data.toString()).to.eql('42')
+          res.close(true)
+
+          server.on('message', function (msg, rsinfo) {
+            var packet = parse(msg)
+            if (packet.ack && (packet.code === '0.00'))
+              return
+
+            try {
+              expect(packet.options.length).to.be.least(1)
+              expect(packet.options[0].name).to.eql('Observe')
+              expect(packet.options[0].value).to.eql(Buffer.from([1]))
+            } catch (err) {
+              return done(err)
+            }
+            done()
+          })
+        })
+      })
+    })
+
     it('should send an empty Observe option', function (done) {
       var req = request({
         port: port
@@ -1087,6 +1177,25 @@ describe('request', function() {
       })
     })
 
+    it('should allow user to send Observe=1', function (done) {
+      var req = request({
+        port: port
+        , observe: 1
+      }).end()
+
+      server.on('message', function (msg, rsinfo) {
+        var packet = parse(msg)
+        try {
+          expect(packet.options[0].name).to.eql('Observe')
+          expect(packet.options[0].value).to.eql(Buffer.from([1]))
+        } catch (err) {
+          return done(err)
+        }
+
+        done()
+      })
+    })
+
     it('should allow multiple notifications', function (done) {
       server.once('message', function(msg, rsinfo) {
         const req = parse(msg)
@@ -1322,11 +1431,11 @@ describe('request', function() {
         sock.addMembership(MULTICAST_ADDR)
         done()
       })
-    });
+    })
 
     afterEach(function() {
       sock.close()
-    });
+    })
 
     it('should be non-confirmable', function (done) {
       var req = doReq()
@@ -1335,7 +1444,7 @@ describe('request', function() {
         var packet = parse(msg)
         expect(packet).to.have.property('confirmable', false)
         done()
-      });
+      })
     })
 
     it('should be responsed with the same token', function (done) {
@@ -1355,7 +1464,7 @@ describe('request', function() {
         })
 
         server.send(toSend, 0, toSend.length, rsinfo.port, rsinfo.address)
-      });
+      })
 
       req.on('response', function (res) {
         var packet = res._packet
@@ -1398,7 +1507,84 @@ describe('request', function() {
       }).end()
     })
 
+    it('should allow for block-wise transfer when using multicast', function (done) {
+      var payload = Buffer.alloc(1536)
+      
+      server = coap.createServer((req, res) => {
+        expect(req.url).to.eql("/hello")
+        res.end(payload)
+      })
+      server.listen(sock)
+
+      var _req = request({
+        host: MULTICAST_ADDR,
+        port: port2,
+        pathname: "/hello",
+        confirmable: false,
+        multicast: true,
+      }).on('response', function (res) {
+        expect(res.payload.toString()).to.eql(payload.toString())
+        done()
+      }).end()
+    })
+    
+    it('should preserve all listeners when using block-wise transfer and multicast', function (done) {
+      var payload = Buffer.alloc(1536)
+      
+      server = coap.createServer((req, res) => {
+        res.end(payload)
+      })
+      server.listen(sock)
+
+      var _req = request({
+        host: MULTICAST_ADDR,
+        port: port2,
+        confirmable: false,
+        multicast: true,
+      })
+
+      _req.on("bestEventEver", function () {
+        done()
+      })
+      
+      _req.on('response', function (res) {
+        expect(res.payload.toString()).to.eql(payload.toString())
+        _req.emit("bestEventEver")
+      }).end()
+    })
+
+    it('should ignore multiple responses from the same hostname when using block2 multicast', function (done) {
+      var payload = Buffer.alloc(1536)
+
+      var counter = 0
+      
+      server = coap.createServer((req, res) => {
+        res.end(payload)
+      })
+      server.listen(sock)
+
+      var server2 = coap.createServer((req, res) => {
+        res.end(payload)
+      })
+      server2.listen(sock)
+
+      var _req = request({
+        host: MULTICAST_ADDR,
+        port: port2,
+        confirmable: false,
+        multicast: true,
+      }).on('response', function (res) {
+        counter++        
+      }).end()
+      
+      setTimeout(function () {
+        expect(counter).to.eql(1)
+        done()
+      }, 45 * 1000)
+
+      fastForward(100, 45 * 1000)
+    })
+
   })
 
-
 })
