@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2015 node-coap contributors.
+ * Copyright (c) 2013-2021 node-coap contributors.
  *
  * node-coap is licensed under an MIT +no-false-attribs license.
  * All rights not explicitly granted in the MIT license are reserved.
@@ -256,7 +256,7 @@ describe('server', function() {
       expect(result.token.length).to.eql(0)
       expect(result.payload.length).to.eql(0)
       done()
-    });
+    })
     server.on('request', function(req, res) {
       res.reset()
     })
@@ -324,26 +324,48 @@ describe('server', function() {
     }
   })
 
-  describe('with the \'Content-Format\' header and a wrong value in the request', function() {
-    it('should return a 5.00 error to the cliend', function(done) {
+  describe('with the \'Content-Format\' header and an unknown value in the request', function() {
+    it('should use the numeric format if the option value is in range', function(done) {
       send(generate({
         options: [{
           name: 'Content-Format'
-          , value: Buffer.of(1541)
+          , value: Buffer.of(0x06, 0x06)
         }]
       }))
 
       client.on('message', function(msg) {
-        var response = parse(msg);
+        var response = parse(msg)
 
-        expect(response.code).to.equal('5.00')
-        expect(response.payload.toString()).to.equal('No matching format found')
+        expect(response.code).to.equal('2.05')
 
         done()
       })
 
-      server.on('request', function(req) {
-        assert(false, 'This should not happen')
+      server.on('request', function(req, res) {
+        expect(req.headers['Content-Format']).to.equal(1542)
+        res.end()
+      })
+    })
+
+    it('should ignore the option if the  option value is not in range', function(done) {
+      send(generate({
+        options: [{
+          name: 'Content-Format'
+          , value: Buffer.of(0xff, 0xff, 0x01)
+        }]
+      }))
+
+      client.on('message', function(msg) {
+        var response = parse(msg)
+
+        expect(response.code).to.equal('2.05')
+
+        done()
+      })
+
+      server.on('request', function(req, res) {
+        expect(req.headers['Content-Format']).to.equal(undefined)
+        res.end()
       })
     })
   })
@@ -654,8 +676,12 @@ describe('server', function() {
       })
 
       setTimeout(function() {
-        // original one plus 4 retries
-        expect(messages).to.eql(5)
+        try {
+          // original one plus 4 retries
+          expect(messages).to.eql(5)
+        } catch (err) {
+          return done(err)
+        }
         done()
       }, 45 * 1000)
 
@@ -898,7 +924,7 @@ describe('server', function() {
         expect(result.ack).to.eql(false)
         expect(result.payload.length).to.eql(0)
 
-        done();
+        done()
       })
     })
 
@@ -1006,7 +1032,7 @@ describe('validate custom server options', function() {
 
   it('use custom piggyBackTimeout time', function(done) {
     var piggyBackTimeout = 10
-    var messages = 0;
+    var messages = 0
     server = coap.createServer({ piggybackReplyMs: piggyBackTimeout })
     server.listen(port)
     server.on('request', function(req, res) {
@@ -1079,7 +1105,7 @@ describe('validate custom server options', function() {
   }
 
   it('should send ACK for non-confirmable message, sendAcksForNonConfirmablePackets=true', function(done) {
-    var messages = 0;
+    var messages = 0
     server = coap.createServer({ sendAcksForNonConfirmablePackets: true })
     server.listen(port)
     server.on('request', function(req, res) {
@@ -1093,7 +1119,7 @@ describe('validate custom server options', function() {
   })
 
   it('should not send ACK for non-confirmable message, sendAcksForNonConfirmablePackets=false', function(done) {
-    var messages = 0;
+    var messages = 0
     server = coap.createServer({ sendAcksForNonConfirmablePackets: false })
     server.listen(port)
     server.on('request', function(req, res) {
@@ -1116,7 +1142,7 @@ describe('validate custom server options', function() {
       res.end('42')
     })
     client.on('message', function(msg) {
-      done();
+      done()
     })
     sendConfirmableMessage()
   })
@@ -1182,3 +1208,159 @@ describe('server LRU', function() {
 
 })
 
+describe('server block cache', function() {
+  var server
+      , port
+      , clientPort
+      , client
+      , clock
+
+  var packet = {
+    confirmable: true
+    , messageId: 4242
+    , token: Buffer.alloc(5)
+  }
+
+  beforeEach(function (done) {
+    clock = sinon.useFakeTimers()
+    port = nextPort()
+    server = coap.createServer()
+    server.listen(port, done)
+  })
+
+  beforeEach(function (done) {
+    clientPort = nextPort()
+    client = dgram.createSocket('udp4')
+    client.bind(clientPort, done)
+  })
+
+  afterEach(function () {
+    clock.restore()
+    client.close()
+    server.close()
+    tk.reset()
+  })
+
+  function send(message) {
+    client.send(message, 0, message.length, port, '127.0.0.1')
+  }
+
+  it('should have block1Cache return {}', function (done) {
+    send(generate(packet))
+    server.on('request', function (req, res) {
+      res.end()
+      expect(server._block1Cache._factory()).to.eql({})
+      done()
+    })
+  })
+
+  it('should have block2Cache return null', function (done) {
+    send(generate(packet))
+    server.on('request', function (req, res) {
+      res.end()
+      expect(server._block2Cache._factory()).to.eql(null)
+      done()
+    })
+  })
+
+})
+
+describe('Client Identifier', function() {
+  var server
+      , port
+      , clientPort
+      , client
+      , clock
+
+  const packet = function(key) {
+    return {
+      confirmable: true
+      , messageId: 4242
+      , token: new Buffer(5)
+      , options: [
+        {name: 2109, value: Buffer.from(key) }
+      ]
+    }
+  }
+
+  beforeEach(function (done) {
+    clock = sinon.useFakeTimers()
+    port = nextPort()
+
+    server = coap.createServer({
+      clientIdentifier: (request) => {
+        const authenticationHeader = request.options.find(o => o.name === '2109')
+
+        if (typeof authenticationHeader !== 'undefined') {
+          return `auth:${authenticationHeader.value.toString()}`
+
+        }
+        return `unauth:${request.rsinfo.address}:${request.rsinfo.port}`
+      },
+    })
+    server.listen(port, done)
+  })
+
+  beforeEach(function (done) {
+    clientPort = nextPort()
+    client = dgram.createSocket('udp4')
+    client.bind(clientPort, done)
+  })
+
+  afterEach(function () {
+    clock.restore()
+    client.close()
+    server.close()
+    tk.reset()
+  })
+
+  function send(message) {
+    client.send(message, 0, message.length, port, '127.0.0.1')
+  }
+
+  it('should share the cache between two requests of the same client', function (done) {
+    let messagesSent = 0
+    let messagesReceived = 0
+
+    server.on('request', function (req, res) {
+      res.end(`${messagesSent}`)
+      messagesSent += 1
+    })
+
+    client.on('message', function(msg) {
+      const result = parse(msg)
+      expect(result.payload.toString(), '0')
+      messagesReceived += 1
+
+      if (messagesReceived === 2) {
+        done()
+      }
+    })
+
+    send(generate(packet('key1')))
+    send(generate(packet('key1')))
+  })
+
+  it('should not share the cache between requests of different clients', function (done) {
+    let messagesSent = 0
+    let messagesReceived = 0
+
+    server.on('request', function (req, res) {
+      res.end(`${messagesSent}`)
+      messagesSent += 1
+    })
+
+    client.on('message', function(msg) {
+      const result = parse(msg)
+      expect(result.payload.toString(), `${messagesReceived}`)
+      messagesReceived += 1
+
+      if (messagesReceived === 2) {
+        done()
+      }
+    })
+
+    send(generate(packet('key1')))
+    send(generate(packet('key2')))
+  })
+})
